@@ -91,11 +91,18 @@ class Autocor_length(Base):
         self.nlags = nlags
 
     def fit(self, data):
+
         magnitude = data[0]
         AC = stattools.acf(magnitude, self.nlags)
         k = next((index for index, value in
                  enumerate(AC) if value < np.exp(-1)), None)
 
+        while k is None:
+            self.nlags = self.nlags + self.nlags
+            AC = stattools.acf(magnitude, self.nlags)
+            k = next((index for index, value in
+                 enumerate(AC) if value < np.exp(-1)), None)
+
         return k
 
 
